__prompt_reset_style="$(! [ "$(command -v tput)" ] || tput sgr0)"
__prompt_reset_cursor="$(
  __prompt_reset_cursor=
  # if echo "$TERM" | grep -q '^xterm\(-\|$\)'
  # then
    __prompt_reset_cursor='\033[1 q'
  # fi
  if echo "$TERM" | grep -q '^linux\(-\|$\)'
  then
    __prompt_reset_cursor='\033[?8c'
  fi
  printf "$__prompt_reset_cursor"
)"

__prompt_reset()
{
  printf "$1" "$__prompt_reset_style$__prompt_reset_cursor"
}
