  # https://wiki.debian.org/chroot
__prompt_chroot="$(! [ -r '/etc/debian_chroot' ] || cat '/etc/debian_chroot')"

__prompt_chroot()
{
  if [ "$__prompt_chroot" ]
  then
    printf "$1" "$__prompt_chroot"
  fi
}
