# https://man.openbsd.org/ssh#SSH_CONNECTION
__prompt_user_host="$(
  if [ "$(id -u)" != "1000" ]
  then
    printf '%s' "$(id -un)"
  fi
  if [ "$SSH_CONNECTION" != "" ]
  then
    printf '@%s' "$(hostname)"
  fi
)"

__prompt_user_host()
{
  if [ "$__prompt_user_host" ]
  then
    printf "$1" "$__prompt_user_host"
  fi
}
